pub struct FallbackTransactionKVStore { /* private fields */ }Expand description
A TransactionKeyValueStoreTrait that falls back to a secondary store for any key for which the primary store returns None.
Will be used to check the local rocksdb store, before falling back to a remote scalable store.
Implementations
Sourceimpl FallbackTransactionKVStore
impl FallbackTransactionKVStore
pub fn new_kv( primary: TransactionKeyValueStore, fallback: TransactionKeyValueStore, metrics: Arc<KeyValueStoreMetrics>, label: &'static str, ) -> TransactionKeyValueStore