pub struct TransactionKeyValueStore { /* private fields */ }Implementations
Sourceimpl TransactionKeyValueStore
impl TransactionKeyValueStore
pub fn new( store_name: &'static str, metrics: Arc<KeyValueStoreMetrics>, inner: Arc<dyn TransactionKeyValueStoreTrait + Send + Sync>, ) -> Self
Sourcepub async fn multi_get(
&self,
transaction_keys: &[TransactionDigest],
effects_keys: &[TransactionDigest],
) -> IotaResult<KVStoreTransactionData>
pub async fn multi_get( &self, transaction_keys: &[TransactionDigest], effects_keys: &[TransactionDigest], ) -> IotaResult<KVStoreTransactionData>
Generic multi_get, allows implementors to get heterogenous values with a single round trip.
pub async fn multi_get_checkpoints( &self, checkpoint_summaries: &[CheckpointSequenceNumber], checkpoint_contents: &[CheckpointSequenceNumber], checkpoint_summaries_by_digest: &[CheckpointDigest], ) -> IotaResult<(Vec<Option<CertifiedCheckpointSummary>>, Vec<Option<CheckpointContents>>, Vec<Option<CertifiedCheckpointSummary>>)>
pub async fn multi_get_checkpoints_summaries( &self, keys: &[CheckpointSequenceNumber], ) -> IotaResult<Vec<Option<CertifiedCheckpointSummary>>>
pub async fn multi_get_checkpoints_contents( &self, keys: &[CheckpointSequenceNumber], ) -> IotaResult<Vec<Option<CheckpointContents>>>
pub async fn multi_get_checkpoints_summaries_by_digest( &self, keys: &[CheckpointDigest], ) -> IotaResult<Vec<Option<CertifiedCheckpointSummary>>>
pub async fn multi_get_tx( &self, keys: &[TransactionDigest], ) -> IotaResult<Vec<Option<Transaction>>>
pub async fn multi_get_fx_by_tx_digest( &self, keys: &[TransactionDigest], ) -> IotaResult<Vec<Option<TransactionEffects>>>
Sourcepub async fn get_tx(&self, digest: TransactionDigest) -> IotaResult<Transaction>
pub async fn get_tx(&self, digest: TransactionDigest) -> IotaResult<Transaction>
Convenience method for fetching single digest, and returning an error if it’s not found. Prefer using multi_get_tx whenever possible.
Sourcepub async fn get_fx_by_tx_digest(
&self,
digest: TransactionDigest,
) -> IotaResult<TransactionEffects>
pub async fn get_fx_by_tx_digest( &self, digest: TransactionDigest, ) -> IotaResult<TransactionEffects>
Convenience method for fetching single digest, and returning an error if it’s not found. Prefer using multi_get_fx_by_tx_digest whenever possible.
Sourcepub async fn get_checkpoint_summary(
&self,
checkpoint: CheckpointSequenceNumber,
) -> IotaResult<CertifiedCheckpointSummary>
pub async fn get_checkpoint_summary( &self, checkpoint: CheckpointSequenceNumber, ) -> IotaResult<CertifiedCheckpointSummary>
Convenience method for fetching single checkpoint, and returning an error if it’s not found. Prefer using multi_get_checkpoints_summaries whenever possible.
Sourcepub async fn get_checkpoint_contents(
&self,
checkpoint: CheckpointSequenceNumber,
) -> IotaResult<CheckpointContents>
pub async fn get_checkpoint_contents( &self, checkpoint: CheckpointSequenceNumber, ) -> IotaResult<CheckpointContents>
Convenience method for fetching single checkpoint, and returning an error if it’s not found. Prefer using multi_get_checkpoints_contents whenever possible.
Sourcepub async fn get_checkpoint_summary_by_digest(
&self,
digest: CheckpointDigest,
) -> IotaResult<CertifiedCheckpointSummary>
pub async fn get_checkpoint_summary_by_digest( &self, digest: CheckpointDigest, ) -> IotaResult<CertifiedCheckpointSummary>
Convenience method for fetching single checkpoint, and returning an error if it’s not found. Prefer using multi_get_checkpoints_summaries_by_digest whenever possible.
pub async fn get_transaction_perpetual_checkpoint( &self, digest: TransactionDigest, ) -> IotaResult<Option<CheckpointSequenceNumber>>
pub async fn get_object( &self, object_id: ObjectId, version: VersionNumber, ) -> IotaResult<Option<Object>>
pub async fn multi_get_objects( &self, object_keys: &[ObjectKey], ) -> IotaResult<Vec<Option<Object>>>
pub async fn multi_get_transactions_perpetual_checkpoints( &self, digests: &[TransactionDigest], ) -> IotaResult<Vec<Option<CheckpointSequenceNumber>>>
pub async fn multi_get_events_by_tx_digests( &self, digests: &[TransactionDigest], ) -> IotaResult<Vec<Option<TransactionEvents>>>